# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/identifier.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/type/shared/v1/identifier.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\"\xc6\x01\n\nIdentifier\x12\x1a\n\x08\x65xchange\x18\x01 \x01(\tR\x08\x65xchange\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12\x38\n\x08provider\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08provider\x12J\n\nasset_type\x18\x04 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetTypeB\xdc\x01\n$com.systemathics.apis.type.shared.v1B\x0fIdentifierProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.identifier_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\017IdentifierProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_IDENTIFIER']._serialized_start=166
  _globals['_IDENTIFIER']._serialized_end=364
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_rsi.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xb7\x02\n\x12IntradayRsiRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x16\n\x06length\x18\x04 \x01(\x05R\x06length\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"l\n\x13IntradayRsiResponse\x12U\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayRsiDataR\x04\x64\x61ta\"t\n\x0fIntradayRsiData\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x10\n\x03rsi\x18\x03 \x01(\x01R\x03rsi2\xcb\x01\n\x12IntradayRsiService\x12\xb4\x01\n\x0bIntradayRsi\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayRsiRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayRsiResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/intraday/rsiB\xa9\x02\n4com.systemathics.apis.services.intraday_analytics.v1B\x10IntradayRsiProtoP\x01\xa2\x02\x04SASI\xaa\x02/Systemathics.Apis.Services.IntradayAnalytics.V1\xca\x02/Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\xe2\x02;Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\\GPBMetadata\xea\x02\x33Systemathics::Apis::Services::IntradayAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday_analytics.v1.intraday_rsi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4com.systemathics.apis.services.intraday_analytics.v1B\020IntradayRsiProtoP\001\242\002\004SASI\252\002/Systemathics.Apis.Services.IntradayAnalytics.V1\312\002/Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\342\002;Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\\GPBMetadata\352\0023Systemathics::Apis::Services::IntradayAnalytics::V1'
  _globals['_INTRADAYRSISERVICE'].methods_by_name['IntradayRsi']._options = None
  _globals['_INTRADAYRSISERVICE'].methods_by_name['IntradayRsi']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/intraday/rsi'
  _globals['_INTRADAYRSIREQUEST']._serialized_start=339
  _globals['_INTRADAYRSIREQUEST']._serialized_end=650
  _globals['_INTRADAYRSIRESPONSE']._serialized_start=652
  _globals['_INTRADAYRSIRESPONSE']._serialized_end=760
  _globals['_INTRADAYRSIDATA']._serialized_start=762
  _globals['_INTRADAYRSIDATA']._serialized_end=878
  _globals['_INTRADAYRSISERVICE']._serialized_start=881
  _globals['_INTRADAYRSISERVICE']._serialized_end=1084
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_bars.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/tick_analytics/v1/tick_bars.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xeb\x03\n\x0fTickBarsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12L\n\x05\x66ield\x18\x03 \x01(\x0e\x32\x36.systemathics.apis.services.tick_analytics.v1.BarPriceR\x05\x66ield\x12\x35\n\x08sampling\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08sampling\x12\x31\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06period\x12\x31\n\x06offset\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06offset\x12\x1e\n\nadjustment\x18\x07 \x01(\x08R\nadjustment\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x08 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\t \x03(\tR\x06reject\"\xdf\x01\n\x10TickBarsResponse\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x14\n\x05\x63lose\x18\x05 \x01(\x01R\x05\x63lose\x12\x16\n\x06volume\x18\x06 \x01(\x03R\x06volume\x12\x14\n\x05\x63ount\x18\x07 \x01(\x05R\x05\x63ount\x12\x12\n\x04vwap\x18\x08 \x01(\x01R\x04vwap*`\n\x08\x42\x61rPrice\x12\x19\n\x15\x42\x41R_PRICE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42\x41R_PRICE_TRADE\x10\x01\x12\x11\n\rBAR_PRICE_BID\x10\x02\x12\x11\n\rBAR_PRICE_ASK\x10\x03\x32\xc0\x01\n\x0fTickBarsService\x12\xac\x01\n\x08TickBars\x12=.systemathics.apis.services.tick_analytics.v1.TickBarsRequest\x1a>.systemathics.apis.services.tick_analytics.v1.TickBarsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/tick-analytics/bars0\x01\x42\x92\x02\n0com.systemathics.apis.services.tick_analytics.v1B\rTickBarsProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_bars_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\rTickBarsProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKBARSSERVICE'].methods_by_name['TickBars']._loaded_options = None
  _globals['_TICKBARSSERVICE'].methods_by_name['TickBars']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/tick-analytics/bars'
  _globals['_BARPRICE']._serialized_start=1028
  _globals['_BARPRICE']._serialized_end=1124
  _globals['_TICKBARSREQUEST']._serialized_start=309
  _globals['_TICKBARSREQUEST']._serialized_end=800
  _globals['_TICKBARSRESPONSE']._serialized_start=803
  _globals['_TICKBARSRESPONSE']._serialized_end=1026
  _globals['_TICKBARSSERVICE']._serialized_start=1127
  _globals['_TICKBARSSERVICE']._serialized_end=1319
# @@protoc_insertion_point(module_scope)
